VERSION 5.00
Begin VB.Form frmTestDLL 
   Caption         =   "Test OCR323 Interface"
   ClientHeight    =   2610
   ClientLeft      =   165
   ClientTop       =   855
   ClientWidth     =   9765
   LinkTopic       =   "Form1"
   LockControls    =   -1  'True
   ScaleHeight     =   2610
   ScaleWidth      =   9765
   StartUpPosition =   3  'Windows Default
   Begin VB.CommandButton cmdOpenAndEnableDevice 
      Caption         =   "Open And Enable Device"
      Height          =   435
      Left            =   7680
      TabIndex        =   4
      Top             =   120
      Width           =   1935
   End
   Begin VB.CommandButton cmdEnableDevice 
      Caption         =   "Enable &Device"
      Enabled         =   0   'False
      Height          =   435
      Left            =   7680
      TabIndex        =   2
      Top             =   1920
      Width           =   1935
   End
   Begin VB.TextBox txtDataReceived 
      BeginProperty Font 
         Name            =   "Courier"
         Size            =   9.75
         Charset         =   0
         Weight          =   400
         Underline       =   0   'False
         Italic          =   0   'False
         Strikethrough   =   0   'False
      EndProperty
      Height          =   1095
      Left            =   120
      MultiLine       =   -1  'True
      TabIndex        =   3
      Top             =   120
      Width           =   7335
   End
   Begin VB.CommandButton cmdOpenDevice 
      Caption         =   "&Open Device"
      Height          =   435
      Left            =   7680
      TabIndex        =   0
      Top             =   720
      Width           =   1935
   End
   Begin VB.CommandButton cmdCloseDevice 
      Caption         =   "&Close Device"
      Enabled         =   0   'False
      Height          =   435
      Left            =   7680
      TabIndex        =   1
      Top             =   1320
      Width           =   1935
   End
   Begin VB.Menu mnuAdvanced 
      Caption         =   "A&dvanced"
   End
End
Attribute VB_Name = "frmTestDLL"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' *******************************************************
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 08:51:57
' Description  :
'              : Test application to demonstrate opening, enabling and
'              : receiving data from an Access OCR device.
'              :
'              : Steps used when connecting to a device.
'              : 1) Open the device.
'              :    This searches for the device and then opens a connection to it.
'              : 2) Enable the device
'              :    This means that the light goes out and the device
'              :    reads documents swiped.
'              : 3) Disable the device
'              :    The device must be disabled manually as the light won't go out
'              :    otherwise.
'              :
' Updates      :
'              :
'              :
' *******************************************************


' Error Constants
Private Const HIDSuccess As Long = 0
Private Const HIDEClosed As Long = 101
Private Const HIDEIllegal As Long = 106
Private Const HIDENoExist As Long = 109
Private Const HIDEFailure As Long = 111

' Status constants
Private Const HIDSOpen As Long = 0
Private Const HIDSClosed As Long = 1


Private WithEvents mobjOCR323 As AccessHID.clsOCR323
Attribute mobjOCR323.VB_VarHelpID = -1


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub SetButtonsEnabled
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 08:55:06
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Enables and disables the relevant buttons displayed.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub SetButtonsEnabled()
  cmdOpenDevice.Enabled = (mobjOCR323.State = HIDSClosed)
  cmdOpenAndEnableDevice.Enabled = (mobjOCR323.State = HIDSClosed)
  cmdCloseDevice.Enabled = (mobjOCR323.State = HIDSOpen)
  
  If mobjOCR323.DeviceEnabled Then
    cmdEnableDevice.Caption = "Disable &Device"
    cmdEnableDevice.Enabled = True
  Else
    cmdEnableDevice.Caption = "Enable &Device"
    cmdEnableDevice.Enabled = (mobjOCR323.State = HIDSOpen)
  End If
  
  If Me.Visible Then
    If cmdOpenDevice.Enabled Then
      cmdOpenDevice.SetFocus
    ElseIf cmdEnableDevice.Enabled Then
      cmdEnableDevice.SetFocus
    End If
  End If

End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub cmdCloseDevice_Click
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 08:58:45
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Close the device.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub cmdCloseDevice_Click()
  mobjOCR323.CloseDevice
  Debug.Print "Close Device ", mobjOCR323.ResultCode
  SetButtonsEnabled
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub cmdEnableDevice_Click
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 08:59:04
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Enable the device.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub cmdEnableDevice_Click()
  mobjOCR323.DeviceEnabled = Not mobjOCR323.DeviceEnabled
  Debug.Print "Enable Device ", mobjOCR323.ResultCode
  SetButtonsEnabled
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub cmdOpenAndEnableDevice_Click
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 08:59:14
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Open and enable the device.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub cmdOpenAndEnableDevice_Click()
  
  If mobjOCR323.OpenDevice = HIDSuccess Then
    mobjOCR323.DeviceEnabled = True
    SetButtonsEnabled
  End If
  
  Debug.Print "Open And Enable Device ", mobjOCR323.ResultCode

End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub cmdOpenDevice_Click
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 08:59:30
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Open the device
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub cmdOpenDevice_Click()
  If mobjOCR323.OpenDevice = HIDSuccess Then SetButtonsEnabled
  Debug.Print "Open Device ", mobjOCR323.ResultCode
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub Form_Load
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 09:02:10
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Initialise the dll.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub Form_Load()
  Set mobjOCR323 = New AccessHID.clsOCR323
  Me.Height = 2200
  Me.Width = 7710
  SetButtonsEnabled
  cmdOpenAndEnableDevice_Click
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub Form_Unload
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 09:00:05
' Inputs       : Cancel:Integer -
' Outputs      : N/A
' Description  :
'              : Make sure the device is disabled before unloading the
'              : dll.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub Form_Unload(Cancel As Integer)
  mobjOCR323.DeviceEnabled = False
  Set mobjOCR323 = Nothing
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub mnuAdvanced_Click
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 09:00:46
' Inputs       : N/A
' Outputs      : N/A
' Description  :
'              : Display open, enable, disable and close command buttons.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub mnuAdvanced_Click()
  
  mnuAdvanced.Enabled = False
  Me.Width = 9885
  Me.Height = 3420
  
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub mobjOCR323_ClosedEvent
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 09:01:17
' Inputs       : ByVal vlngResultCode:Long -
' Outputs      : N/A
' Description  :
'              : Connection to the device is closed.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub mobjOCR323_ClosedEvent(ByVal vlngResultCode As Long)
  Debug.Print "ClosedEvent", vlngResultCode
  SetButtonsEnabled
End Sub


' *******************************************************
' Routine Name : (PRIVATE in FORM) Sub mobjOCR323_DataEvent
' Written By   : William. D. Wensley
' Programmer   : William. D. Wensley [Access Ltd]
' Date Written : 05/07/2008 -- 09:01:33
' Inputs       : ByVal vstrData:String -
' Outputs      : N/A
' Description  :
'              : Data receive from the device.
'              :
' Updates      :
'              :
'              :
' *******************************************************
Private Sub mobjOCR323_DataEvent(ByVal vstrData As String)

  txtDataReceived.Text = vstrData
  Debug.Print "DataEvent", mobjOCR323.ResultCode
  Debug.Print mobjOCR323.LastRead & vbCrLf & vbCrLf
  
End Sub

